pub struct PDAStackCtx {
pub sym: SegmentDelimSyms,
pub seg_start: usize,
}Fields
sym: SegmentDelimSymsseg_start: usizeTrait Implementations
Sourceimpl PartialEq<PDAStackCtx> for SegmentDelimSyms
impl PartialEq<PDAStackCtx> for SegmentDelimSyms
Sourcefn eq(&self, other: &PDAStackCtx) -> bool
fn eq(&self, other: &PDAStackCtx) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialEq for PDAStackCtx
impl PartialEq for PDAStackCtx
Sourcefn eq(&self, other: &PDAStackCtx) -> bool
fn eq(&self, other: &PDAStackCtx) -> bool
Tests for
self and other values to be equal, and is used by ==.Auto Trait Implementations
impl Freeze for PDAStackCtx
impl RefUnwindSafe for PDAStackCtx
impl Send for PDAStackCtx
impl Sync for PDAStackCtx
impl Unpin for PDAStackCtx
impl UnsafeUnpin for PDAStackCtx
impl UnwindSafe for PDAStackCtx